importPackage(java.lang);
importPackage(java.sql);
importPackage(java.util);
importPackage(java.io);
importPackage(Packages.javax.xml);
importPackage(Packages.javax.xml.parsers);
importPackage(Packages.javax.xml.transform);
importPackage(Packages.javax.xml.transform.dom);
importPackage(Packages.javax.xml.transform.stream);
importPackage(Packages.com.alarmpoint.integrations.nnmi.mg)

// Set host to NNMi Server IP Address, Set port to the NNMi Web Services configured port
var host = "localhost";
var port = "80";

/**
 * Retrieve the Incident using its id.
 * @param id
 * @return Incident
 * @throws RemoteException
 * @throws NmsIncidentFaultException0
 */
function getIncident(params)
{ 
  var nnmiUser = params.remove("nnmiUser");
  var nnmiPass = params.remove("nnmiPass");
  var id = params.get( "Incident_ID" );
  var wrapper = new NetworkNodeManagerMobileGatewayWrapper(host, port, nnmiUser, nnmiPass);

  try{
    return wrapper.getIncident(id);
  }catch(e){
    return e;
  }
}

/**
 * Retrieve the Incidents based on the IncidentFilter provided.
 * The incident filter outlines what incidents to return from NNMi.
 * @param filter (Filter must contain the appropriate IncidentFilter)
 * @return List<Incident>
 * @throws RemoteException
 * @throws NmsIncidentFaultException0
 */
function getIncidents(params) 
{  
  var nnmiUser = params.remove("nnmiUser");
  var nnmiPass = params.remove("nnmiPass");
  var filter = params.get( "filter" );
  var max_messages = params.get( "maxcount" );
  var max_messages = params.get( "maxcount" );
  var wrapper = new NetworkNodeManagerMobileGatewayWrapper(host, port, nnmiUser, nnmiPass);

  try{
    return wrapper.getIncidents(filter);
  }catch(e){
    return e;
  }
}


/**
 * Retrieve the Child Incidents based on the Incident ID of the parent provided.
 * @param Parent Incident ID
 * @return List<Incident>
 * @throws RemoteException
 * @throws NmsIncidentFaultException0
 */
function getChildIncidents(params) 
{  
  var nnmiUser = params.remove("nnmiUser");
  var nnmiPass = params.remove("nnmiPass");
  var filter = params.get( "Incident_ID" );
  var wrapper = new NetworkNodeManagerMobileGatewayWrapper(host, port, nnmiUser, nnmiPass);

  try{
    return wrapper.getChildIncidents(filter);
  }catch(e){
    return e;
  }
}

/**
 * Update the incident specified by its ID with the associated notes
 * @param id
 * @param notes
 * @return UpdateNotesResponse
 * @throws RemoteException
 * @throws NmsIncidentFaultException0
 */
function addAnnotation(params)
{ 
  var nnmiUser = params.remove("nnmiUser");
  var nnmiPass = params.remove("nnmiPass");
  var id = params.get( "Incident_ID" );
  var text = params.get( "Annotation_Text" );
  var wrapper = new NetworkNodeManagerMobileGatewayWrapper(host, port, nnmiUser, nnmiPass);

  try{
      wrapper.updateNotes(id, text);
  }catch(e){
    return e;
  }
}

/**
 * Update the incident specified by its ID with the associated priority, lifecycle state and assigned to fields.
 * Update each method depending if the passed in values exist or not.
 * @param Incident_ID
 * @param Priority
 * @param LifecycleState
 * @param AssignedTo
 * @return UpdateLifecycleStateResponse
 * @throws RemoteException
 * @throws NmsIncidentFaultException0
 */
function saveIncident(params) 
{  
  var nnmiUser = params.remove("nnmiUser");
  var nnmiPass = params.remove("nnmiPass");
  var id = params.get( "Incident_ID" );
  var priority = params.get( "Priority" );
  var lifecycleState = params.get( "LifecycleState" );
  var assignedTo = params.get( "AssignedTo" );
  var wrapper = new NetworkNodeManagerMobileGatewayWrapper(host, port, nnmiUser, nnmiPass);
  
  try{
    if (priority != null) {
      wrapper.updatePriority(id, priority);
    }
    if (lifecycleState != null) {
      wrapper.updateLifecycleState(id, lifecycleState);
    }
    if (assignedTo != null) {
      wrapper.updateAssignedTo(id, assignedTo);
    }
  }catch(e){
    return e;
  }
}

/**
 * Retrieve the Node using its name.
 * @param nodeName
 * @return Node
 * @throws RemoteException
 * @throws NmsNodeFaultException0
 */
function getNode(params)
{ 
  var nnmiUser = params.remove("nnmiUser");
  var nnmiPass = params.remove("nnmiPass");
  var nodeName = params.get( "nodeName" );
  var wrapper = new NetworkNodeManagerMobileGatewayWrapper(host, port, nnmiUser, nnmiPass);

  try{
      return wrapper.getNode(nodeName);
  }catch(e){
    return e;
  }
}

/**
 * Verifies that the given credentials are correct otherwise it throws an NmsIncidentFaultException0 exception.
 * @return boolean
 * @throws RemoteException
 * @throws NmsIncidentFaultException0
 */
function validateCreds(params)
{
  var nnmiUser = params.remove("nnmiUser");
  var nnmiPass = params.remove("nnmiPass");
  
  var wrapper = new NetworkNodeManagerMobileGatewayWrapper(host, port, nnmiUser, nnmiPass);
  try{
    wrapper.validateCredentials();
  }catch(e){
    return e;
  }
  return null; 
}

/**
 * Retrieve the _interface Source Object using its name.
 * @param sourceName
 * @return _interface
 * @throws UnsupportedOperationException
 * @throws RemoteException
 * @throws NmsInterfaceFaultException0
 */
function getInterface(params) 
{  
  var nnmiUser = params.remove("nnmiUser");
  var nnmiPass = params.remove("nnmiPass");
  var sourceObject = params.remove("sourceObject");
  var wrapper = new NetworkNodeManagerMobileGatewayWrapper(host, port, nnmiUser, nnmiPass);

  try{
      return wrapper.getInterface(sourceObject);
  }catch(e){
    return e;
  }
}

/**
 * Retrieve the IpAddress Source Object using its name.
 * @param sourceName
 * @return IpAddress
 * @throws UnsupportedOperationException
 * @throws RemoteException
 * @throws NmsIPAddressFaultException0
 */
function getIPAddress(params) 
{  
  var nnmiUser = params.remove("nnmiUser");
  var nnmiPass = params.remove("nnmiPass");
  var sourceObject = params.remove("sourceObject");
  var wrapper = new NetworkNodeManagerMobileGatewayWrapper(host, port, nnmiUser, nnmiPass);

  try{
      return wrapper.getIPAddress(sourceObject);
  }catch(e){
    return e;
  }
}

/**
 * Retrieve the IpSubnet Source Object using its name.
 * @param sourceName
 * @return IpSubnet
 * @throws UnsupportedOperationException
 * @throws RemoteException
 * @throws NmsIPSubnetFaultException0
 */
function getIPSubnet(params) 
{  
  var nnmiUser = params.remove("nnmiUser");
  var nnmiPass = params.remove("nnmiPass");
  var sourceObject = params.remove("sourceObject");
  var wrapper = new NetworkNodeManagerMobileGatewayWrapper(host, port, nnmiUser, nnmiPass);

  try{
      return wrapper.getIPSubnet(sourceObject);
  }catch(e){
    return e;
  }
}

/**
 * Retrieve the L2Connection Source Object using its name.
 * @param sourceName
 * @return L2Connection
 * @throws UnsupportedOperationException
 * @throws RemoteException
 * @throws NmsL2ConnectionFaultException0
 */
function getL2Connection(params) 
{  
  var nnmiUser = params.remove("nnmiUser");
  var nnmiPass = params.remove("nnmiPass");
  var sourceObject = params.remove("sourceObject");
  var wrapper = new NetworkNodeManagerMobileGatewayWrapper(host, port, nnmiUser, nnmiPass);

  try{
      return wrapper.getL2Connection(sourceObject);
  }catch(e){
    return e;
  }
}

/**
 * Retrieve a list of Assignable users for a incident
 * @return a list of Assignable users for a incident
 * @throws RemoteException
 * @throws Exception 
 * @throws NmsIncidentFaultException0
 */
function getAssignToList(params) 
{  
  var nnmiUser = params.remove("nnmiUser");
  var nnmiPass = params.remove("nnmiPass");
  var wrapper = new NetworkNodeManagerMobileGatewayWrapper(host, port, nnmiUser, nnmiPass);

  try{
      return wrapper.getAssignToList();
  }catch(e){
    return e;
  }
}
